==> eurelis_llmatoolkit-1.0.0rc1-py3-none-any.whl: eurelis_llmatoolkit/utils/output/logging_console_output.py <==
import inspect
import logging
import sys
from typing import List, Sequence

from eurelis_llmatoolkit.utils.output.output import Output


class LoggingConsoleOutput(Output):
    """
    Base output class for non-verbose printing on the console
    """

    def __init__(self, level: int = logging.INFO):
        """
        Constructor
        Args:
            level(int): logging level, default to logging.INFO
        """
        logging_format = "%(asctime)s - %(name)s %(levelname)s %(message)s"
        logging.basicConfig(format=logging_format, level=level)  # NOSONAR

    @property
    def logger(self) -> logging.Logger:
        return LoggingConsoleOutput._get_logger()

    @staticmethod
    def _get_logger() -> logging.Logger:
        frame = sys._getframe(3)
        module = inspect.getmodule(frame)
        return logging.getLogger(module.__name__ if module else __name__)

    def print(self, *args, **kwargs):
        """
        Print method, proxy for the logger print method
        Args:
            *args: positional arguments
            **kwargs: keyword arguments

        Returns:

        """
        self.logger.info(*args, **kwargs)

    def critical_print(self, *args, **kwargs):
        """
        Critical Print method, proxy for the logger print method
        Args:
            *args: positional arguments
            **kwargs: keyword arguments

        Returns:

        """
        self.logger.critical(*args, **kwargs)

    def verbose_print(self, *args, **kwargs):
        """
        Verbose print method, does nothing in the base version
        Args:
            *args: positional arguments
            **kwargs: keyword arguments

        Returns:
        """
        self.logger.debug(*args, **kwargs)

    def status(self, msg: str, handler):
        """
        Status method, proxy for the logger status method
        Args:
            msg: text message to display
            handler: function or lambda without a parameter

        Returns:
            the result of the handler method

        """
        self.logger.info(f"[START] {msg}")
        value = handler()
        self.logger.info(f"[END] {msg}")

        return value

    def verbose_status(self, msg, handler):
        """
        Status method, proxy for the logger status method, does nothing much in the base version
        Args:
            msg: text message to display
            handler: function or lambda without a parameter

        Returns:
            the result of the handler method

        """
        self.logger.debug(f"[START] {msg}")
        value = handler()
        self.logger.debug(f"[END] {msg}")

        return value

    def print_table(self, items, columns: Sequence[str], row_extractor, **kwargs):
        """
        Print table method, will create a table and print it them
        Args:
            items: list or iterator for row items
            columns: list of columns names
            row_extractor: lambda method with two parameters (index and item) to extract row values
            kwargs: key value arguments to provide to the Table constructor

        Returns:

        """
        pass

    def verbose_print_table(
        self, items, columns: Sequence[str], row_extractor, **kwargs
    ):
        """
        Print table method, will create a table and print it them, does nothing in the base version
        Args:
            items: list or iterator for row items
            columns: list of columns names
            row_extractor: lambda method with two parameters (index and item) to extract row values
            kwargs: key value arguments to provide to the Table constructor

        Returns:

        """
        pass

==> eurelis_llmatoolkit-1.1.0rc2-py3-none-any.whl: eurelis_llmatoolkit/utils/output/logging_console_output.py <==
import inspect
import logging
from logging.config import fileConfig

import sys
from typing import List, Sequence

from eurelis_llmatoolkit.utils.output.output import Output


class LoggingConsoleOutput(Output):
    """
    Base output class for non-verbose printing on the console
    """

    def __init__(self, level: int = logging.INFO, config: str = None, logger_name: str = None):
        """
        Constructor
        Args:
            level(int): logging level, default to logging.INFO
        """
        logging_format = "%(asctime)s - %(name)s %(levelname)s %(message)s"
        logging.basicConfig(format=logging_format, level=level)  # NOSONAR
        fileConfig(config)

        # If a logger_name is provided, retrieve the specific logger
        self._logger_name = logger_name

    @property
    def logger(self) -> logging.Logger:
        return LoggingConsoleOutput._get_logger(self._logger_name)

    @staticmethod
    def _get_logger(logger_name: str|None = None) -> logging.Logger:
        if logger_name:
            return logging.getLogger(logger_name)
        else:
            frame = sys._getframe(3)
            module = inspect.getmodule(frame)
            return logging.getLogger(module.__name__ if module else __name__)

    def print(self, *args, **kwargs):
        """
        Print method, proxy for the logger print method
        Args:
            *args: positional arguments
            **kwargs: keyword arguments

        Returns:

        """
        self.logger.info(*args, **kwargs)

    def critical_print(self, *args, **kwargs):
        """
        Critical Print method, proxy for the logger print method
        Args:
            *args: positional arguments
            **kwargs: keyword arguments

        Returns:

        """
        self.logger.critical(*args, **kwargs)

    def verbose_print(self, *args, **kwargs):
        """
        Verbose print method, does nothing in the base version
        Args:
            *args: positional arguments
            **kwargs: keyword arguments

        Returns:
        """
        self.logger.debug(*args, **kwargs)

    def status(self, msg: str, handler):
        """
        Status method, proxy for the logger status method
        Args:
            msg: text message to display
            handler: function or lambda without a parameter

        Returns:
            the result of the handler method

        """
        self.logger.info(f"[START] {msg}")
        value = handler()
        self.logger.info(f"[END] {msg}")

        return value

    def verbose_status(self, msg, handler):
        """
        Status method, proxy for the logger status method, does nothing much in the base version
        Args:
            msg: text message to display
            handler: function or lambda without a parameter

        Returns:
            the result of the handler method

        """
        self.logger.debug(f"[START] {msg}")
        value = handler()
        self.logger.debug(f"[END] {msg}")

        return value

    def print_table(self, items, columns: Sequence[str], row_extractor, **kwargs):
        """
        Print table method, will create a table and print it them
        Args:
            items: list or iterator for row items
            columns: list of columns names
            row_extractor: lambda method with two parameters (index and item) to extract row values
            kwargs: key value arguments to provide to the Table constructor

        Returns:

        """
        pass

    def verbose_print_table(
        self, items, columns: Sequence[str], row_extractor, **kwargs
    ):
        """
        Print table method, will create a table and print it them, does nothing in the base version
        Args:
            items: list or iterator for row items
            columns: list of columns names
            row_extractor: lambda method with two parameters (index and item) to extract row values
            kwargs: key value arguments to provide to the Table constructor

        Returns:

        """
        pass
